@@ -1,6 +1,6 @@
 """
-hdlg - Modern cross-platform GUI for hdl-dump.
-Copyright (C) 2021 rlaphoenix
+hdlg - Modern GUI for hdl-dump.
+Copyright (C) 2021-2022 rlaphoenix
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,9 +24,12 @@ from PySide2.QtWidgets import QApplication
 
 from hdlg.config import Directories
 from hdlg.ui.main import Main
+from hdlg.utils import require_admin
 
 
 def main():
+    require_admin()
+
     os.environ["QT_AUTO_SCREEN_SCALE_FACTOR"] = "1"
     QtCore.QCoreApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling)
 
